@@ -1,10 +1,10 @@
+// -*- C++ -*-
+
 /* 
  * Gnome Chemistry Utils
  * element.cc 
  *
- * Copyright (C) 2002-2006
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -50,6 +50,15 @@ static void ReadValue (char const *source, GcuValue &value)
 	value.delta = (*buf == '(')? strtol (buf + 1, NULL, 10): 0;
 }
 
+static void ReadDimensionalValue (char const *source, GcuDimensionalValue &value)
+{
+	char *buf, *dot;
+	value.value = strtod (source, &buf);
+	dot = strchr (source, '.');
+	value.prec = (dot)? buf - dot - 1: 0;
+	value.delta = (*buf == '(')? strtol (buf + 1, NULL, 10): 0;
+}
+
 namespace gcu
 {
 
@@ -77,7 +86,7 @@ EltTable Table;
 
 EltTable::EltTable()
 {
-	bindtextdomain (GETTEXT_PACKAGE, DATADIR"/locale");
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 #ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
@@ -93,7 +102,7 @@ EltTable::EltTable()
 	Langs["it"] = _("Italian");
 	Langs["pl"] = _("Polish");
 	Langs["ru"] = _("Russian");
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils/elements.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/elements.xml")))
 	{
 		g_error (_("Can't find and read elements.xml"));
 	}
@@ -421,7 +430,7 @@ void Element::LoadRadii ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils/radii.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/radii.xml")))
 	{
 		g_error (_("Can't find and read radii.xml"));
 	}
@@ -492,7 +501,7 @@ void Element::LoadRadii ()
 						xmlFree (buf);
 					buf = (char*) xmlGetProp (child, (xmlChar*) "value");
 					if (buf) {
-						ReadValue (buf, (GcuValue&) radius->value) ;
+						ReadDimensionalValue (buf, radius->value) ;
 						radius->value.unit = (*it).c_str ();
 						Elt->m_radii.push_back (radius);
 						xmlFree (buf);
@@ -521,7 +530,7 @@ void Element::LoadElectronicProps ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils/elecprops.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/elecprops.xml")))
 	{
 		g_error (_("Can't find and read elecprops.xml"));
 	}
@@ -679,7 +688,7 @@ void Element::LoadIsotopes ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils/isotopes.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/isotopes.xml")))
 	{
 		g_error (_("Can't find and read isotopes.xml"));
 	}
