@@ -93,8 +93,8 @@ static void on_file_print (GtkWidget *widget, void *data)
 	pc = gnome_print_job_get_context (gpj);
 	gnome_print_beginpage (pc, (const guchar*)"");
 	gdouble width, height;
-	gnome_print_config_get_double (config, GNOME_PRINT_KEY_PAPER_WIDTH, &width);
-	gnome_print_config_get_double (config, GNOME_PRINT_KEY_PAPER_HEIGHT, &height);
+	gnome_print_config_get_double (config, (const guchar*) GNOME_PRINT_KEY_PAPER_WIDTH, &width);
+	gnome_print_config_get_double (config, (const guchar*) GNOME_PRINT_KEY_PAPER_HEIGHT, &height);
 	gtk_chem3d_viewer_print (viewer, pc, width, height);
 	gnome_print_showpage (pc);
 	g_object_unref (pc);
@@ -129,13 +129,24 @@ static void on_display (GtkRadioAction *action, GtkRadioAction *current, GObject
 	g_object_set (obj, "display3d", gtk_radio_action_get_current_value (action), NULL);
 }
 
+static void on_about_activate_url (GtkAboutDialog *about, const gchar *url, gpointer data)
+{
+	GnomeVFSResult error = gnome_vfs_url_show(url);
+	if (error != GNOME_VFS_OK) {
+		g_print("GnomeVFSResult while trying to launch URL in about dialog: error %u\n", error);
+	}
+}
+
 static void on_about (GtkWidget *widget, void *data)
 {
-	char * authors[] = {"Jean Bréfort", NULL};
-//	char * documentors[] = {NULL};
-	char license[] = "This program is free software; you can redistribute it and/or\n" 
+	const gchar * authors[] = {"Jean Bréfort", NULL};
+	const gchar * comments = _("GChem3D is a molecular structures viewer for Gnome");
+	/* const gchar * documentors[] = {NULL}; */
+	const gchar * copyright = "Copyright \xc2\xa9 2004-2006 Jean Bréfort\n";
+	const gchar * license =
+		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
- 		"published by the Free Software Foundation; either version 2 of the\n"
+		"published by the Free Software Foundation; either version 2 of the\n"
 		"License, or (at your option) any later version.\n\n"
 		"This program is distributed in the hope that it will be useful,\n"
 		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
@@ -145,32 +156,34 @@ static void on_about (GtkWidget *widget, void *data)
 		"along with this program; if not, write to the Free Software\n"
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1307\n"
 		"USA";
-/* Note to translators: replace the following string with the appropriate credits for you lang */
-	char *translator_credits = _("translator_credits");
+	
+	gtk_about_dialog_set_url_hook(on_about_activate_url, NULL, NULL);
+
+	/* Note to translators: replace the following string with the appropriate credits for you lang */
+	const gchar * translator_credits = _("translator_credits");
 	gtk_show_about_dialog (NULL,
-					"name", "GChem3D",
-					"authors", authors,
-					"comments", _("GChem3D is a molecular structures viewer for Gnome"),
-					"copyright", _("(C) 2004-2006 by Jean Bréfort"),
-					"license", license,
-					"translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? 
-											(const char *)translator_credits : NULL,
-					"version", VERSION,
-					"website", "http://www.nongnu.org/gchemutils",
-					NULL);
+	                       "name", "GChem3D",
+	                       "authors", authors,
+	                       "comments", comments,
+	                       "copyright", copyright,
+	                       "license", license,
+	                       "translator_credits", translator_credits,
+	                       "version", VERSION,
+	                       "website", "http://www.nongnu.org/gchemutils",
+	                       NULL);
 }
 
 static GtkActionEntry entries[] = {
   { "FileMenu", NULL, N_("_File") },
 	  { "Open", GTK_STOCK_OPEN, N_("_Open..."), "<control>O",
 		  N_("Open a file"), G_CALLBACK (on_file_open) },
-	  { "Print", GTK_STOCK_OPEN, N_("_Print..."), "<control>P",
+	  { "Print", GTK_STOCK_PRINT, N_("_Print..."), "<control>P",
 		  N_("Print the current scene"), G_CALLBACK (on_file_print) },
  	  { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
 		  N_("Quit GChem3D"), G_CALLBACK (on_quit) },
   { "ViewMenu", NULL, N_("_View") },
   { "HelpMenu", NULL, N_("_Help") },
-	  { "About", NULL, N_("_About"), NULL,
+	  { "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
 		  N_("About GChem3D"), G_CALLBACK (on_about) }
 };
 
@@ -216,7 +229,7 @@ static char *display3d = NULL;
 
 static GOptionEntry options[] = 
 {
-	{ "version", 'v', 0, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, N_("Prints GChem3d Viewer version"), NULL },
+	{ "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, N_("Prints GChem3d Viewer version"), NULL },
 	{ "bgcolor", 'b', 0, G_OPTION_ARG_STRING, &bgcolor, N_("Background color: white, black or #rrggbb (default is black)"), NULL },
 	{ "display3d", 'd', 0, G_OPTION_ARG_STRING, &display3d, N_("How molecules are displayed; possible values are BallnStick (the default) and SpaceFill"), NULL },
 	{ NULL }
@@ -234,6 +247,7 @@ int main(int argc, char *argv[])
 	GError *error = NULL;
 	GOptionContext *context;
 
+	textdomain (GETTEXT_PACKAGE);
 	gtk_init (&argc, &argv);
 	if (!gnome_vfs_init ()) {
 		printf ("Could not initialize GnomeVFS\n");
@@ -308,7 +322,7 @@ int main(int argc, char *argv[])
 
 	if (display3d) {
 		Display3DMode mode = BALL_AND_STICK;
-		if (!strcmp (display3d, "SpaceFill"))
+		if (strcmp (display3d, "SpaceFill"))
 			mode = SPACEFILL;
 		else if (strcmp (display3d, "BallnStick"))
 			g_warning (_("Unknown display mode"));
